/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void firstDayChanged(int index);
   void horizontalHeaderChanged(int index);
   void verticalHeaderChanged(int index);

   QCalendarWidget *calendar;

   QComboBox *firstDayCombo;
   QComboBox *horizontalCombo;
   QComboBox *verticalCombo;
   QCheckBox *gridCheckBox;
   QCheckBox *navCheckBox;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   calendar = new QCalendarWidget;
   calendar->setMinimumDate(QDate(1950, 1, 1));
   calendar->setMaximumDate(QDate(2100, 1, 1));
   calendar->setGridVisible(true);

   QLabel *firstDayLabel = new QLabel("Week starts on:");

   firstDayCombo = new QComboBox;
   firstDayCombo->addItem("Sunday",    Qt::Sunday);
   firstDayCombo->addItem("Monday",    Qt::Monday);
   firstDayCombo->addItem("Tuesday",   Qt::Tuesday);
   firstDayCombo->addItem("Wednesday", Qt::Wednesday);
   firstDayCombo->addItem("Thursday",  Qt::Thursday);
   firstDayCombo->addItem("Friday",    Qt::Friday);
   firstDayCombo->addItem("Saturday",  Qt::Saturday);

   QLabel *horizontalLabel = new QLabel("Horizontal header:");

   horizontalCombo = new QComboBox;
   horizontalCombo->addItem("Short day names", QCalendarWidget::ShortDayNames);
   horizontalCombo->addItem("Single letter day names", QCalendarWidget::SingleLetterDayNames);
   horizontalCombo->addItem("None", QCalendarWidget::NoHorizontalHeader);
   horizontalCombo->setCurrentIndex(0);

   QLabel *verticalLabel = new QLabel("Vertical header:");

   verticalCombo = new QComboBox;
   verticalCombo->addItem("Show Week Numbers",QCalendarWidget::ISOWeekNumbers);
   verticalCombo->addItem("None", QCalendarWidget::NoVerticalHeader);

   gridCheckBox = new QCheckBox("&Show Grid");
   gridCheckBox->setChecked(calendar->isGridVisible());

   navCheckBox = new QCheckBox("&Navigation bar");
   navCheckBox->setChecked(true);

   QPushButton *pb_1 = new QPushButton();
   pb_1->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setContentsMargins(75, 45, 75, 25);
   grid1->setHorizontalSpacing(35);

   grid1->addWidget(calendar, 0, 0, 1, 5);
   grid1->addItem(new QSpacerItem(0, 25), 1, 0, 1, 5);

   grid1->addWidget(firstDayLabel, 2, 1);
   grid1->addWidget(firstDayCombo, 2, 2, 1, 2);

   grid1->addWidget(horizontalLabel, 3, 1);
   grid1->addWidget(horizontalCombo, 3, 2, 1, 2);

   grid1->addWidget(verticalLabel, 4, 1);
   grid1->addWidget(verticalCombo, 4, 2, 1, 2);

   grid1->addWidget(gridCheckBox,  5, 2);
   grid1->addWidget(navCheckBox,   5, 3);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(pb_1);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid1);
   layoutMain->addSpacing(25);
   layoutMain->addLayout(layout1);

   connect(firstDayCombo,   cs_mp_cast<int>(&QComboBox::currentIndexChanged), this, &MainWindow::firstDayChanged);
   connect(horizontalCombo, cs_mp_cast<int>(&QComboBox::currentIndexChanged), this, &MainWindow::horizontalHeaderChanged);
   connect(verticalCombo,   cs_mp_cast<int>(&QComboBox::currentIndexChanged), this, &MainWindow::verticalHeaderChanged);

   connect(gridCheckBox,    &QCheckBox::toggled, calendar, &QCalendarWidget::setGridVisible);
   connect(navCheckBox,     &QCheckBox::toggled, calendar, &QCalendarWidget::setNavigationBarVisible);

   connect(pb_1, &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::firstDayChanged(int index)
{
   calendar->setFirstDayOfWeek(Qt::DayOfWeek(firstDayCombo->itemData(index).toInt()));
}

void MainWindow::horizontalHeaderChanged(int index)
{
   calendar->setHorizontalHeaderFormat(
         QCalendarWidget::HorizontalHeaderFormat(horizontalCombo->itemData(index).toInt()));
}

void MainWindow::verticalHeaderChanged(int index)
{
   calendar->setVerticalHeaderFormat(
         QCalendarWidget::VerticalHeaderFormat(verticalCombo->itemData(index).toInt()));
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

